==> haskell-configurator-pg-0.2.9-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 configurator-pg
version:              0.2.9
visibility:           public
id:                   configurator-pg-0.2.9-Djkyl37N8DkISBSRsqBSou
key:                  configurator-pg-0.2.9-Djkyl37N8DkISBSRsqBSou
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  407b15f36e75a28ba52dc4b9c9f8403d
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/configurator-pg-0.2.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.9-Djkyl37N8DkISBSRsqBSou
depends:
    base-4.16.4.0 containers-0.6.5.1
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD
    protolude-0.3.4-erquiU8swABHjzXTMSoGn
    scientific-0.3.7.0-8x4tZ4xzXsRTNLFKkeuvD text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.10-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.10
visibility:           public
id:                   configurator-pg-0.2.10-1ZlMukL19koIsNp5wFZZdW
key:                  configurator-pg-0.2.10-1ZlMukL19koIsNp5wFZZdW
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  3e69ddac1c33697ac9b6396198982c60
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/configurator-pg-0.2.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.10-1ZlMukL19koIsNp5wFZZdW
depends:
    base-4.17.2.1 containers-0.6.7
    megaparsec-9.6.1-6pqHq8BNT2333chbXCRu9H
    protolude-0.3.5-1ESZO9jnM8B3jFqxMIweDq
    scientific-0.3.7.0-FVWP8DVCKbGBwiSARe0xui text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
